@@ -27,14 +27,14 @@ class PyHtmlGui:
                  template_dir     : str             = "",
                  electron_app_dir : str             = None,
                  base_template    : str             = "pyHtmlGuiBase.html",
-                 size             : tuple[int, int] = (800, 600),
                  on_view_connected: typing.Callable = None,
                  on_view_disconnected: typing.Callable = None,
+                 size             : tuple[int, int] = None,
                  position         : tuple[int, int] = None,
-                 mode             : str             = "chrome",
+                 browser          : str             = "default",
                  executable       : str             = None,
                  listen_host      : str             = "127.0.0.1",
-                 listen_port      : int             = 8042,
+                 listen_port      : int             = 8000,
                  shared_secret    : str             = None,
                  auto_reload      : bool            = False,
                  single_instance  : bool            = True
@@ -53,7 +53,7 @@ class PyHtmlGui:
         :param on_view_disconnected: callback is called when a frontend websocket is disconnected
                                         arguments passed: "nr of view instances", "nr of websocket connections"
         :param position: window position
-        :param mode: chrome | electron
+        :param browser: default | chrome | electron
         :param executable: path to chrome/electron executable, if needed
         :param listen_host:
         :param listen_port:
@@ -72,7 +72,7 @@ class PyHtmlGui:
         self.on_view_connected_callback = on_view_connected
         self.on_view_disconnected_callback = on_view_disconnected
         self.position = position
-        self.mode = mode
+        self.browser = browser
         self.executable = executable
         self.electron_app_dir = electron_app_dir
         if shared_secret == "":
@@ -112,7 +112,7 @@ class PyHtmlGui:
             raise Exception("Static dir '%s' not found" % self.static_dir)
 
         self.template_loader = jinja2.FileSystemLoader(searchpath=[self._template_dir, self.template_dir])
-        self._template_env = jinja2.Environment(loader=self.template_loader)
+        self._template_env = jinja2.Environment(loader=self.template_loader, autoescape=jinja2.select_autoescape())
 
         self._gui_instances = []
 
@@ -146,7 +146,7 @@ class PyHtmlGui:
         env = None
         target_host = "127.0.0.1" if self.listen_host == "0.0.0.0" else self.listen_host
 
-        if self.mode == "electron":
+        if self.browser == "electron":
             args = [self.electron_app_dir, ]
             env = os.environ.copy()
             env.update({
@@ -159,7 +159,7 @@ class PyHtmlGui:
             if self.shared_secret is not None:
                 args[0] = "%s?token=%s" % (args[0], self.shared_secret)
         if self._browser is None:
-            self._browser = Browser(self.mode, self.executable)
+            self._browser = Browser(self.browser, self.executable)
         self._browser.open(args, env=env)
 
     # /main.html
@@ -201,7 +201,8 @@ class PyHtmlGui:
             self._gui_instances.append(instance)
 
         if self.on_view_connected_callback is not None:
-            connections = sum([i.connections_count for i in self._gui_instances]) +1  # +1 because connetion gets only added in loop later
+            connections = sum([i.connections_count for i in self._gui_instances]) + 1
+            # +1 because connection gets only added in loop later
             self.on_view_connected_callback(len(self._gui_instances), connections)
 
         instance.websocket_loop(websocket_connection)  # loop while connected
@@ -214,7 +215,6 @@ class PyHtmlGui:
             connections = sum([i.connections_count for i in self._gui_instances])
             self.on_view_disconnected_callback(len(self._gui_instances), connections)
 
-
     def add_file_to_monitor(self, file_to_monitor, class_name) -> None:
         if self.auto_reload is False:
             return
