@@ -1,30 +1,34 @@
 from __future__ import annotations
 import typing
 import weakref
-import uuid
 import traceback
 import time
 import random
 import string
 from typing import TYPE_CHECKING
+
+from markupsafe import Markup
+
 if TYPE_CHECKING:
     from pyhtmlgui.lib.observable import Observable
 from pyhtmlgui.pyhtmlguiInstance import PyHtmlGuiInstance
 
 CHARACTERS = list(string.ascii_lowercase + string.digits)
 
+
 class PyHtmlView:
+    TEMPLATE_STR  = None
     TEMPLATE_FILE = None
-    TEMPLATE_STR = None
-    WRAPPER_ELEMENT = "pyview"
-    WRAPPER_EXTRAS = ""
+    DOM_ELEMENT = "div"
+    DOM_ELEMENT_CLASS = ""
+    DOM_ELEMENT_EXTRAS = ""
 
     def __init__(self,
                  subject,
                  parent:  typing.Union[PyHtmlView, PyHtmlGuiInstance],
                  **kwargs):
 
-        self.uid = "%s_%s" % ( self.__class__.__name__, "".join(random.choices(CHARACTERS,k=16)))
+        self.uid = "pv%s" % ("".join(random.choices(CHARACTERS, k=16)))
         self.is_visible = False
 
         parent._add_child(self)
@@ -75,16 +79,21 @@ class PyHtmlView:
         if html is None:
             return None
         self.__last_rendered = time.time()
-        if self.WRAPPER_ELEMENT is None:
-            return html
+        if self.DOM_ELEMENT is None:
+            return Markup(html)
         else:
-            s = "<%(w_el)s id='%(uid)s' %(w_ex)s>%(content)s</%(w_el)s>"
-            return s % {
-                "w_el" : self.WRAPPER_ELEMENT,
-                "w_ex" : self.WRAPPER_EXTRAS,
+            cls = self.DOM_ELEMENT_CLASS
+            if cls == "":   cls = self.__class__.__name__
+            if cls is None: cls = ""
+            if cls != "":   cls = 'class="%s"' % cls
+
+            return Markup('<%(el)s %(cls)s id="%(uid)s" %(ex)s>%(html)s</%(el)s>' % {
+                "el"  : self.DOM_ELEMENT,
+                "cls" : cls,
                 "uid" : self.uid,
-                "content" : html,
-            }
+                "ex"  : self.DOM_ELEMENT_EXTRAS,
+                "html": html,
+            })
 
     def update(self) -> None:
         """
@@ -117,7 +126,8 @@ class PyHtmlView:
         """
         if self.is_visible is True and remove_from_dom is True:
             self.call_javascript("pyhtmlgui.remove_element", [self.uid], skip_results=True)
-        self.set_visible(False)
+        if self.is_visible is True:
+            self.set_visible(False)
         self.parent._remove_child(self)
         for child in self._children:
             child.delete(remove_from_dom=False)
@@ -138,7 +148,8 @@ class PyHtmlView:
                 except Exception:
                     pass
             for child in self._children:
-                child.set_visible(False)
+                if child.is_visible is True:
+                    child.set_visible(False)
         else:
             self.is_visible = True
             for observable, target in self._observables:
@@ -147,7 +158,7 @@ class PyHtmlView:
                 except Exception:
                     pass
 
-    def call_javascript(self, js_function_name, args, skip_results=False):
+    def call_javascript(self, js_function_name, args=None, skip_results=False):
         """
         Call javascript function in frontend.
         :param js_function_name: Name of javascript function
@@ -180,10 +191,12 @@ class PyHtmlView:
         if self._subject is None:  # Observed object died before render
             return None
 
-        self.set_visible(True)
         for child in self._children:
             child.__was_rendered = False
 
+        if self.is_visible is False:
+            self.set_visible(True)
+
         try:
             html = self._instance.get_template(self).render({"pyview": self})
         except Exception:
